@@ -462,28 +462,26 @@ def get_generators(pcp: PCP, charset_mapping: dict[str,int]) -> dict[Composition
       for charset in rule.require:
         required[charset_mapping[charset]] = 1
     
-    # Look at required characters in require_subset. This is done by creating a different generator for each subset. To ensure these generators are unique, we will create a different generator for each possible combination of the options, with character restrictions to prevent characters not in the combination.
+    # Look at required characters in require_subset. This is done by creating a different generator for each subset.
+    def _add_to_generators(generator):
+      if generator not in generators:
+        generators[generator] = set()
+      if restriction is not None:
+        generators[generator].add(restriction)
+    
     if rule.require_subset is not None:
       options = set(map(lambda x: charset_mapping[x], rule.require_subset.options or charset_mapping.keys()))
-      for count in range(rule.require_subset.count, len(options) + 1):
-        for include in itertools.combinations(options, count):
-          new_required = [1 if index in include else required[index] for index in range(len(required))]
-          
-          exclude = options - set(include)
-          new_max_allowed = [
-            max(0, new_required[index]) if index in exclude else max_allowed[index] 
-            for index in range(len(required))]
-          
-          generator = CompositionGenerator(rule.min_length, new_required, new_max_allowed) 
+      for include in itertools.combinations(options, rule.require_subset.count):
+        new_required = [max(1, required[index]) if index in include else required[index] 
+                        for index in range(len(required))]        
+        _add_to_generators(CompositionGenerator(rule.min_length, new_required, max_allowed))
     else:
-      generator = CompositionGenerator(rule.min_length, required, max_allowed) 
+      _add_to_generators(CompositionGenerator(rule.min_length, required, max_allowed)) 
       
-    # Add the generator and associated restriction
-    if generator not in generators:
-      generators[generator] = set()
-    if restriction is not None:
-      generators[generator].add(restriction)
 
+    # Add the generator and associated restriction
+  print(generators)
+  
   return generators
         
 
