@@ -109,13 +109,19 @@ class PCP():
       else:
         return json.dumps({'rules': [_to_json_compatible_object(rule) for rule in self.rules]})
 
-    # Charsets need to set as null unused charsets from the default charsets
-    charsets = self.charsets.copy()
-    for key in (ALPHABET_CHARSETS.keys() if 'alphabet' in charsets else DEFAULT_CHARSETS.keys()):
-      if key not in charsets:
-        charsets[key] = None
+    # Get a diff between the defined charset and the default charset. Only dump this diff.
+    charsets_diff: dict[str,str] = {}
+    default_charset = ALPHABET_CHARSETS if 'alphabet' in self.charsets else DEFAULT_CHARSETS
+        
+    for name, charset in self.charsets.items():
+      if name not in default_charset or set(charset) != set(default_charset[name]):
+        charsets_diff[name] = charset
     
-    return json.dumps({'charsets': charsets, 'rules': [_to_json_compatible_object(rule) for rule in self.rules]})
+    for name in default_charset.keys():
+      if name not in self.charsets:
+        charsets_diff[name] = None
+    
+    return json.dumps({'charsets': charsets_diff, 'rules': [_to_json_compatible_object(rule) for rule in self.rules]})
     
     
   @staticmethod
